from typing import Optional

import requests

from image_depot import DepotType
from .base import Depot


class Dig268608(Depot):
    @classmethod
    def depot_type(cls) -> DepotType:
        return DepotType.Dig268608

    # 上传图片, 二进制内容
    def _upload(self, content) -> Optional[str]:
        file_name = self._random_file_name(content)
        if not file_name:
            return None
        files = {
            "file": (file_name, content)
        }
        response = requests.post('https://www.268608.com/upload/localhost', files=files)
        if response.status_code != 200:
            return self._set_error(f'upload fail. code: {response.status_code}. content: {response.text}')
        data = response.json()
        url = data.get('url')
        if data.get('code') != 200 or not url:
            return self._set_error(f'response error. {response.text}')
        return url



from typing import Optional

import requests

from image_depot import DepotType
from .base import Depot

TOKEN = ''
FOLDER_ID = 0


def set_config(token: str, folder_id=0):
    """
    配置的获取请参考: http://doc.tucang.cc/project-1/doc-7/
    :param token:
    :param folder_id:
    :return:
    """
    global TOKEN, FOLDER_ID
    TOKEN = token
    FOLDER_ID = folder_id


class Tucang(Depot):
    @classmethod
    def depot_type(cls) -> DepotType:
        return DepotType.Tucang

    # 上传图片, 二进制内容
    def _upload(self, content) -> Optional[str]:
        if not TOKEN:
            return self._set_error('token is empty')
        tmp_filename = self._random_file_name(content)
        if not tmp_filename:
            return None
        data = {
            'token': TOKEN,
        }
        if FOLDER_ID:
            data['folderId'] = FOLDER_ID
        files = {
            "file": (tmp_filename, content)
        }
        response = requests.post("https://tucang.cc/api/v1/upload", files=files, data=data)
        if response.status_code != 200:
            return self._set_error(f'request fail. code: {response.status_code}')
        #  检查返回数据
        data = response.json()
        url = data.get('data', {}).get('url')
        if not data.get('success') or not url:
            return self._set_error(f'server return error. {response.text}')
        return url



"""
@author hujing
"""
from .depot.sm_ms import set_config as sm_ms_set_config
from .depot.github import set_config as github_set_config
from .depot.img_url import set_config as img_url_set_config
from .depot.hua_ban import set_config as hua_ban_set_config
from .depot.xywm import set_config as xywm_set_config
from .depot.pomf_se import set_config as pomf_se_set_config
from .depot.tucnag import set_config as tucang_set_config


def _default_set_config(*arg1, **arg2):
    """
    此函数无实际意义. 为了向后兼容
    若未来某个图床失效了, 需要将其实现删除
    此时, 为了保证调用方升级后不保存, set_config 函数需要保留
    可以使用此函数进行替代
    :param arg1:
    :param arg2:
    :return:
    """
    pass


class DepotConfig:
    SmMs = sm_ms_set_config
    Github = github_set_config
    ImgUrl = img_url_set_config
    HuaBan = hua_ban_set_config
    Xywm = xywm_set_config
    PomfSe = pomf_se_set_config
    Tucang = tucang_set_config
